# CLU - Common Loop Utils

This repository contains common functionality for writing ML training loops. The
goal is to make trainings loops short and readable (but moving common tasks to
small libraries) without removing the flexibility required for research.

As this point we are not accepting contributions. Please fork the repository if
you want to extend the libraries for your use case.
